@@ -187,6 +187,12 @@ KateGitBlamePluginView::KateGitBlamePluginView(KateGitBlamePlugin *plugin, KText
 
 KateGitBlamePluginView::~KateGitBlamePluginView()
 {
+    // ensure to kill, we segfault otherwise
+    m_blameInfoProc.kill();
+    m_blameInfoProc.waitForFinished();
+    m_showProc.kill();
+    m_showProc.waitForFinished();
+
     m_mainWindow->guiFactory()->removeClient(this);
 }
 
@@ -199,15 +205,13 @@ QPointer<KTextEditor::Document> KateGitBlamePluginView::activeDocument() const
 {
     KTextEditor::View *view = m_mainWindow->activeView();
     if (view && view->document()) {
-        return m_mainWindow->activeView()->document();
+        return view->document();
     }
     return nullptr;
 }
 
 void KateGitBlamePluginView::viewChanged(KTextEditor::View *view)
 {
-    m_blamedLines.clear();
-
     if (m_lastView) {
         qobject_cast<KTextEditor::InlineNoteInterface *>(m_lastView)->unregisterInlineNoteProvider(&m_inlineNoteProvider);
     }
@@ -217,17 +221,30 @@ void KateGitBlamePluginView::viewChanged(KTextEditor::View *view)
         return;
     }
 
+    const auto url = view->document()->url();
+    // This can happen for example if you were looking at a "temporary"
+    // view like a diff. => do nothing
+    if (url.isEmpty() || !url.isValid()) {
+        return;
+    }
+
     qobject_cast<KTextEditor::InlineNoteInterface *>(view)->registerInlineNoteProvider(&m_inlineNoteProvider);
 
-    startBlameProcess(view->document()->url());
+    startBlameProcess(url);
 }
 
 void KateGitBlamePluginView::startBlameProcess(const QUrl &url)
 {
-    if (url.isEmpty() || !url.isValid() || m_blameUrl == url) {
+    // same document? maybe split view? => no work to do, reuse the result we already have
+    if (m_blameUrl == url) {
         return;
     }
 
+    // clear everything
+    m_blameUrl.clear();
+    m_blamedLines.clear();
+    m_blameInfoForHash.clear();
+
     // Kill any existing process...
     if (m_blameInfoProc.state() != QProcess::NotRunning) {
         m_blameInfoProc.kill();
@@ -263,6 +280,21 @@ void KateGitBlamePluginView::showCommitInfo(const QString &hash, KTextEditor::Vi
     startShowProcess(view->document()->url(), hash);
 }
 
+static int nextBlockStart(const QByteArray &out, int from)
+{
+    int next = out.indexOf('\t', from);
+    // tab must be the first character in line for next block
+    if (next > 0 && out[next - 1] != '\n') {
+        next++;
+        // move forward one line
+        next = out.indexOf('\n', next);
+        // try to look for another tab char
+        next = out.indexOf('\t', next);
+        // if not found => end
+    }
+    return next;
+}
+
 void KateGitBlamePluginView::blameFinished(int /*exitCode*/, QProcess::ExitStatus /*exitStatus*/)
 {
     const QByteArray out = m_blameInfoProc.readAllStandardOutput();
@@ -326,7 +358,7 @@ void KateGitBlamePluginView::blameFinished(int /*exitCode*/, QProcess::ExitStatu
             m_blamedLines.back().lineText = out.mid(from, pos - from);
 
             start = next + 1;
-            next = out.indexOf('\t', start);
+            next = nextBlockStart(out, start);
             if (next == -1)
                 break;
             next = out.indexOf('\n', next);
@@ -380,7 +412,7 @@ void KateGitBlamePluginView::blameFinished(int /*exitCode*/, QProcess::ExitStatu
         m_blamedLines.back().lineText = out.mid(from, pos - from);
 
         start = next + 1;
-        next = out.indexOf('\t', start);
+        next = nextBlockStart(out, start);
         if (next == -1)
             break;
         next = out.indexOf('\n', next);
